<?php //timeline.inc.php        template file for highcharts timeline graph     

/**
 * @param $args
 *
 * @return string
 */
function fetch_multistack($args)
{
    //pass args into template 
    //return JSON code  
    //declare JS variables and JSON object
    $highchart_scale = grab_array_var($args, 'highcharts_scale', '');

    // Allow for height to be passed for resizing
    $height = grab_array_var($args, 'height', 500);

    // Remove some of the underscores
    $args['title'] = str_replace("_", " ", $args['title']);
    $args['title'] = encode_form_val($args['title']);

    // Special export settings for local exporting
    $filename = str_replace(array("  ", " ", ":", "__", "_-_"),
                            array(" ", "_", "-", "_", "-"),
                            strtolower($args['title']));
    $filename = trim($filename, "_");
    if (empty($filename)) { $filename = "multistacked_graph"; }
    $exporting = "";
    if (get_option('highcharts_local_export_server', 1)) {
        $exporting = "exporting: {
            url: '".get_base_url()."/includes/components/highcharts/exporting-server/index.php',
            sourceHeight: $('#{$args['container']}').height(),
            sourceWidth: $('#{$args['container']}').width(),
            filename: '{$filename}',
            chartOptions: { chart: { spacing: [25, 25, 25, 25], marginRight: 30 },
                            title: { text: '"._("Multistacked Performance Graph")."' } }
         },";
    }

    //begin heredoc string syntax 
    $graph = <<<GRAPH
        
        var COUNT = {$args['count']}; //total rrd entries fetched
        var START = {$args['start']};   //Date.UTC(2011, 1, 21) ->added below for correct datatype
        var TITLE = '{$args['title']}'; 
        var CONTAINER = '{$args['container']}'; 
        var SCALE = '$highchart_scale';
        
        //reset default colors 
		Highcharts.setOptions({
			colors: ['#058DC7', '#50B432', '#ED561B', '#DDDF00', '#24CBE5', '#64E572', '#FF9655', '#FFF263', '#6AF9C4'] 
		}); 
    
        //data points added below for correct datatype interpretation               
        //use browser's timezone offset for date        
        Highcharts.setOptions({
            global: { useUTC: false },
        });
                
            var chart;
            $(document).ready(function() {
                chart = new Highcharts.Chart({
                    {$exporting}
                    chart: {
                        renderTo: CONTAINER,
                        zoomType: 'x',
                        spacingRight: 20,
                        height: {$height},
                        animation: false
                    },
                    credits: {
                        enabled: false
                    },
                    title: {
                        //insert host/service name here 
                        text: TITLE
                    },
                    subtitle: {
                        text: ""
                    },
                    xAxis: {
                        
                        type: 'datetime',
                        maxZoom: {$args['increment']}*1000,  //max zoom is 5 minutes 
                        title: {
                            text: null
                        }
                    },
                    yAxis: [
GRAPH;

    // Add the different axis
    $axis = array();
    foreach ($args['UOM'] as $uom) {
        $axis[] = '{
                            title: {
                                text: ""
                            },
                            labels: {
                                formatter: function() {
                                    return this.value + "' . $uom . '";
                                }
                            },
                            startOnTick: false,
                            showFirstLabel: false,
                            type: SCALE
                        }';
    }
    $graph .= implode(',', $axis);

    $stacking = "";
    if ($args['linetype'] == 'stacked') {
        $stacking = "stacking: 'normal',";
    }

    $graph .= <<<GRAPH

                    ],
                    tooltip: {
                        shared: true
                    },
                    legend: {
                        enabled: true
                    },
                    plotOptions: {
                        series: {
                           fillOpacity: 0.5
                        },
                        area: {
                            lineWidth: 1,{$stacking}
                            marker: {
                                enabled: false,
                                states: {
                                    hover: {
                                        enabled: true,
                                        radius: 5
                                    }
                                }
                            },
                            shadow: false,
                            states: {
                                hover: {
                                    lineWidth: 1                        
                                }
                            }
                        },
                        line: {
                            lineWidth: 2,
                            marker: {
                                enabled: false,
                                states: {
                                    hover: {
                                        enabled: true,
                                        radius: 5
                                    }
                                }
                            },
                            shadow: false,
                            states: {
                                hover: {
                                    lineWidth: 2                        
                                }
                            }
                        },
                        spline: {
                            lineWidth: 2,
                            marker: {
                                enabled: false,
                                states: {
                                    hover: {
                                        enabled: true,
                                        radius: 5
                                    }
                                }
                            },
                            shadow: false,
                            states: {
                                hover: {
                                    lineWidth: 2                        
                                }
                            }
                        }
                    },
                
                    series: [
GRAPH;
//end heredoc syntax 
    //loop for multiple data sets in perfdata
    $series = array();
    $uom_on_graph = array();
    for ($i = 0; $i < count($args['datastrings']); $i++) {
        // Remove some more underscores
        $series_name = encode_form_val(str_replace("_", " ", $args['names'][$i]));


        $found = false;
        foreach ($uom_on_graph as $uom => $v) {
            if ($uom == $args['UOM'][$i]) {
                $uom_to_use = $v;
                $found = true;
                break;
            }
        }

        if (!$found) {
            $uom_on_graph[$args['UOM'][$i]] = $i;
            $uom_to_use = $i;
        }

        $yaxis = "";
        if (count($args['datastrings']) > 1) {
            $yaxis = "yAxis: " . $uom_to_use . ",";
        }

        $linetype = $args['linetype'];
        if ($linetype == 'stacked') {
            $linetype = 'area';
        }

        $series[] = "
                    {
                        type: \"{$linetype}\",
                        name: \"{$series_name}\",  //service description or host check,
                        pointInterval: {$args['increment']}*1000,            //time scale, 5mn 
                        pointStart: {$args['start']},    //start time  
                        data: [
                            " . implode(', ', $args['datastrings'][$i]) . "
                        ],
                        " . $yaxis . "
                        tooltip: {
                            valueSuffix: ' " . $args['UOM'][$i] . "'
                        },
                        animation: false
                    }
                    ";
    } //end loop

    $graph .= implode(',', $series);

    $graph .= "
                    ]  //series data closed                     
                });             
            });"; //end graph 

    return $graph;
} //end fetch_timeline() 
